# Generated by Django 5.0.2 on 2024-03-18 08:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('example_pdf', '0005_modela_modelx'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='modelx',
            name='model_filed7',
        ),
        migrations.AddField(
            model_name='modelx',
            name='model_filed7',
            field=models.ManyToManyField(blank=True, null=True, to='example_pdf.modeltype', verbose_name='模型X字段7'),
        ),
    ]
