# Generated by Django 5.0.2 on 2024-03-18 08:17

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('example_pdf', '0004_modeltype_modelx'),
    ]

    operations = [
        migrations.AddField(
            model_name='modela',
            name='modelx',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='model_as', to='example_pdf.modelx'),
            preserve_default=False,
        ),
    ]
