# Generated by Django 5.0.2 on 2024-03-18 03:44

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('example_pdf', '0003_modelc'),
    ]

    operations = [
        migrations.CreateModel(
            name='ModelType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='名称')),
            ],
            options={
                'verbose_name': '选项类型',
                'verbose_name_plural': '选项类型',
            },
        ),
        migrations.CreateModel(
            name='ModelX',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('model_filed1', models.CharField(max_length=100, verbose_name='模型X字段1')),
                ('model_filed2', models.CharField(max_length=100, verbose_name='模型X字段2')),
                ('model_filed3', models.CharField(max_length=100, verbose_name='模型X字段3')),
                ('model_filed4', models.CharField(max_length=100, verbose_name='模型X字段4')),
                ('model_filed5', models.CharField(max_length=100, verbose_name='模型X字段5')),
                ('model_filed6', models.CharField(max_length=100, verbose_name='模型X字段6')),
                ('model_filed7', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='example_pdf.modeltype', verbose_name='模型X字段7')),
            ],
        ),
    ]
