# Generated by Django 5.0.2 on 2024-03-07 02:34

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TodoType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='名称')),
            ],
            options={
                'verbose_name': '待办类型',
                'verbose_name_plural': '待办类型',
            },
        ),
        migrations.CreateModel(
            name='TodoItem',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='标题')),
                ('subtitle', models.CharField(blank=True, max_length=255, null=True, verbose_name='副标题')),
                ('sys_name', models.CharField(default='', max_length=100, verbose_name='系统名称')),
                ('todo_uid', models.CharField(max_length=100, unique=True, verbose_name='待办UID')),
                ('redirect_url', models.URLField(verbose_name='待办跳转URL')),
                ('assignee', models.CharField(max_length=255, verbose_name='待办人')),
                ('assignee_id', models.CharField(max_length=100, verbose_name='待办人ID')),
                ('initiator', models.CharField(blank=True, max_length=255, null=True, verbose_name='发起人')),
                ('initiator_id', models.CharField(blank=True, max_length=100, null=True, verbose_name='发起人ID')),
                ('handler', models.CharField(blank=True, max_length=255, null=True, verbose_name='经办人')),
                ('handler_id', models.CharField(blank=True, max_length=100, null=True, verbose_name='经办人ID')),
                ('reminder_count', models.IntegerField(default=0, verbose_name='催办次数')),
                ('notes', models.TextField(blank=True, null=True, verbose_name='备注')),
                ('is_completed', models.BooleanField(default=False, verbose_name='已完成状态')),
                ('completion_time', models.DateTimeField(blank=True, null=True, verbose_name='办结时间')),
                ('completer', models.CharField(blank=True, max_length=255, null=True, verbose_name='办结人')),
                ('completer_id', models.CharField(blank=True, max_length=100, null=True, verbose_name='办结人ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='更新时间')),
                ('due_date', models.DateField(blank=True, null=True, verbose_name='截止日期')),
                ('type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='example_pdf.todotype', verbose_name='类型')),
            ],
            options={
                'verbose_name': '待办事项',
                'verbose_name_plural': '待办事项',
            },
        ),
    ]
